# 4.2.0

-   Upgrade dependencies
-   #97 Support a Max Queue Size for Buffered Messages
-   #94 Set no delay for the first connection
-   #106 package.json module points to non-existing file
-   #107 Make isWebSocket check more lenient to support iOS Safari
-   #102 added startClosed option
-   #104 fix error event type
